package com.kakao.sdk.auth

import android.net.Uri
import com.kakao.sdk.common.KakaoSdk

/**
 * @suppress
 */
object UriUtility {

    fun authorizeUri(
        clientId: String,
        agt: String? = null,
        redirectUri: String,
        scopes: List<String>? = null,
        channelPublicIds: List<String>? = null,
        serviceTerms: List<String>? = null,
        autoLogin: Boolean? = null,
        approvalType: String = "individual"
    ): Uri {
        val builder = Uri.Builder()
            .scheme(com.kakao.sdk.network.Constants.SCHEME)
            .authority(KakaoSdk.serverHosts.kauth).path(Constants.AUTHORIZE_PATH)
            .appendQueryParameter(Constants.CLIENT_ID, clientId)
            .appendQueryParameter(Constants.REDIRECT_URI, redirectUri)
            .appendQueryParameter(Constants.RESPONSE_TYPE, Constants.CODE)
            .appendQueryParameter(Constants.APPROVAL_TYPE, approvalType).apply {
                agt?.let { appendQueryParameter(Constants.AGT, agt) }
                if (!scopes.isNullOrEmpty()) {
                    appendQueryParameter(Constants.SCOPE, scopes.joinToString(","))
                }
                if (!channelPublicIds.isNullOrEmpty()) {
                    appendQueryParameter(
                        "plus_friend_public_id",
                        channelPublicIds.joinToString(",")
                    )
                }
                if (!serviceTerms.isNullOrEmpty()) {
                    appendQueryParameter("service_terms", serviceTerms.joinToString(","))
                }
                autoLogin?.let { appendQueryParameter("auto_login", it.toString()) }
            }
        return builder.build()
    }
}